@@ -644,7 +644,9 @@ def classify(smile: str, category0: str) -> CategoryResult:
     else:
         # return CategoryResult(Category0.Error, Category1.Default, Category2.Default, Category3.Default,
         #                       Category4.Default, "-", Hydrolysis.Default, Steric_Hindrance.Default)
-        raise Exception('Illegal Category!')
+        # raise Exception('Illegal Category: {} - {}'.format(smile, category0))
+        return CategoryResult(Category0.Others, Category1.Default, Category2.Default, Category3.Default,
+                              Category4.Default, "-", Hydrolysis.Default, Steric_Hindrance.Default)
 
 
 # if __name__ == '__main__':
